# [Zope-tests] OK : winbot / ztk_10 py_244_win32

buildbot at winbot.zope.org buildbot at winbot.zope.org
Thu Feb 3 16:00:46 EST 2011

- Previous message: [Zope-tests] OK : winbot / ztk_dev py_270_win64
- Next message: [Zope-tests] OK : winbot / ztk_10 py_254_win32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : winbot / ztk_10 py_244_win32
    Build: http://winbot.zope.org/builders/ztk_10%20py_244_win32/builds/199

    Build Reason: The Nightly scheduler named 'ztk_10 py_244_win32_nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://winbot.zope.org/

- Previous message: [Zope-tests] OK : winbot / ztk_dev py_270_win64
- Next message: [Zope-tests] OK : winbot / ztk_10 py_254_win32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list